@@ -98,7 +98,7 @@ bool indent_step_change( Buffer & )
   history.push_back( std::string() );
   if( Screen::get_string( "Spaces to add when indenting a block (^C to abort): ", history ) <= 0 )
     return false;
-  std::string & s = history.back();
+  const std::string & s = history.back();
   int i;
   if( !RC::parse_int( s, i ) || i < 1 || i >= Screen::width() )
     { Screen::show_message( "Value out of range" ); history.pop_back();
@@ -121,7 +121,7 @@ bool keep_lines_change( Buffer & )
   history.push_back( std::string() );
   if( Screen::get_string( "Lines to keep for PgUp/PgDn or -1 for 1/2 window (^C to abort): ", history ) <= 0 )
     return false;
-  std::string & s = history.back();
+  const std::string & s = history.back();
   int i;
   if( !RC::parse_int( s, i ) || i < -1 || i >= Screen::height() )
     { Screen::show_message( "Value out of range" ); history.pop_back();
@@ -144,7 +144,7 @@ bool lmargin_change( Buffer & buffer )
   history.push_back( std::string() );
   if( Screen::get_string( "Left margin (^C to abort): ", history ) <= 0 )
     return false;
-  std::string & s = history.back();
+  const std::string & s = history.back();
   int i;
   if( RC::parse_int( s, i ) && buffer.options.set_lmargin( i - 1 ) )
     return true;
@@ -167,7 +167,7 @@ bool max_windows_change( Buffer & )
   history.push_back( std::string() );
   if( Screen::get_string( "Max number of windows to show or 0 for no limit (^C to abort): ", history ) <= 0 )
     return false;
-  std::string & s = history.back();
+  const std::string & s = history.back();
   int i;
   if( !RC::parse_int( s, i ) || i < 0 || i > Screen::max_windows() )
     { Screen::show_message( "Value out of range" ); history.pop_back();
@@ -197,7 +197,7 @@ bool rmargin_change( Buffer & buffer )
   history.push_back( std::string() );
   if( Screen::get_string( "Right margin (^C to abort): ", history ) <= 0 )
     return false;
-  std::string & s = history.back();
+  const std::string & s = history.back();
   int i;
   if( RC::parse_int( s, i ) && buffer.options.set_rmargin( i - 1 ) )
     return true;
