@@ -76,7 +76,7 @@ enum Optcode
   read_only = 'o', word_wrap = 'w',
   no_auto_unmark = 256, no_backup, /*no_beep,*/ no_exit_ask, no_ignore_case,
   no_rectangle_mode, no_search_wrap, no_smart_home, no_auto_indent,
-  no_overwrite, no_read_only, no_word_wrap,
+  no_overwrite, no_read_only, no_word_wrap
   };
 
 const Arg_parser::Option options[] =
